==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-runner/translations/razor-runner_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Razor-runner Settings</source>
        <translation>Impostazioni del Razor-runner</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Posizionamento:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Mostra su:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Scorciatoia:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="70"/>
        <source>Top edge of screen</source>
        <translation>Bordo superiore dello schermo</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Center of screen</source>
        <translation>Centro dello schermo</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="77"/>
        <source>Monitor where the mouse</source>
        <translation>Vedi dove è il mouse</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="82"/>
        <source>Always on %1 monitor</source>
        <translation>Sempre sul monitor %1 </translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Lanciatore di applicazioni</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="91"/>
        <source>Configure razor-runner</source>
        <translation>Configura Razor-runner</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="291"/>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Premi &quot;%1&quot; per vedere il dialogo.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="221"/>
        <source>History</source>
        <translation>Storia</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="307"/>
        <source>Mathematics</source>
        <translation>Matematica</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-runner/translations/razor-runner_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Razor-runner Settings</source>
        <translation>Impostazioni di Razor-runner</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <source>Positioning:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <source>Show on:</source>
        <translation>Mostra su:</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Scorciatoia:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation>Bordo superiore dello schermo</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation>Centro dello schermo</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation>Vedi dove è il mouse</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation>Sempre sullo schermo %1</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Application launcher </source>
        <translation>Avviatore di applicazioni</translation>
    </message>
    <message>
        <source>Configure razor-runner</source>
        <translation>Configura Razor-runner</translation>
    </message>
    <message>
        <source>Clear razor-runner History</source>
        <translation>Cancella la cronologia di razor-runner</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Premi &quot;%1&quot; per vedere la finestra di dialogo.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Mathematics</source>
        <translation>Matematica</translation>
    </message>
    <message>
        <source>Razor Power Management</source>
        <translation>Gestione energetica di Razor</translation>
    </message>
</context>
</TS>
